library(haven)
library(tidyverse)
library(psych)
library(ggplot2)
library(ggside)
library(labelled)

data <- read_sav("C:\\Users\\LocalAdmin\\OneDrive - Universität Regensburg\\Dokumente - U365_HW_Psy7_Berlin\\Review Stress in Hirn\\PreFinal\\Supplement\\Henze_et_al_cortisol_structure.sav")
vars_in_paper<-c("cortisol_increase", "AUCg", "AUCi",
                 "left_thalamus_volume", "right_thalamus_volume", 
                 "left_caudatus_volume", "right_caudatus_volume", 
                 "left_accumbens_volume", "right_accumbens_volume", 
                 "left_putamen_volume", "right_putamen_volume", 
                 "left_hippocampus_volume", "right_hippocampus_volume", 
                 "left_amygdala_volume", "right_amygdala_volume", 
                 "left_cACC_thickness", "right_cACC_thickness", 
                 "left_rACC_thickness", "right_rACC_thickness", 
                 "left_PCC_thickness", "right_PCC_thickness",  
                 "left_parahippocampus_thickness", "right_parahippocampus_thickness", 
                 "left_lateral_orbitofrontal_thickness", "right_lateral_orbitofrontal_thickness", 
                 "left_medial_orbitofrontal_thickness", "right_medial_orbitofrontal_thickness")
vars_labels<-c("Cortisol increase", "AUCg", "AUCi",
               "Left thalamus volume", "Right thalamus volume", 
               "Left caudatus volume", "Right caudatus volume", 
               "Left accumbens volume", "Right accumbens volume", 
               "Left putamen volume", "Right putamen volume", 
               "Left hippocampus volume", "Right hippocampus volume", 
               "Left amygdala volume", "Right amygdala volume", 
               "Left cACC thickness", "Right cACC thickness", 
               "Left rACC thickness", "Right rACC thickness", 
               "Left PCC thickness", "Right PCC thickness",  
               "Left parahippocampus thickness", "Right parahippocampus thickness", 
               "Left lateral orbitofrontal thickness", "Right lateral orbitofrontal thickness", 
               "Left medial orbitofrontal thickness", "Right medial orbitofrontal thickness")

corrs.data<-round(cor(data[vars_in_paper], use = "pairwise.complete.obs"),2)
psych::corPlot(corrs.data, trailing=T, MAR=10, cex=0.7, labels=vars_labels, main="",xlas=2)

corrs.data.w<-round(cor(data[data$sex==1,vars_in_paper], use = "pairwise.complete.obs"),2)
corrs.data.m<-round(cor(data[data$sex==0,vars_in_paper], use = "pairwise.complete.obs"),2)
corrs.data.wm<-corrs.data.w
#unten Korrs Männer
corrs.data.wm[lower.tri(corrs.data.wm, diag = F)]<-corrs.data.m[lower.tri(corrs.data.m, diag = F)==T]
psych::corPlot(corrs.data.wm, xlas=2, MAR=10, cex=0.7, diag=FALSE, labels=vars_labels, main="")

p<-ggplot(data, aes(cortisol_increase,left_thalamus_volume, group=sex)) + 
    geom_point(aes(shape = sex,color = sex), size=2) +
    geom_xsidedensity(aes(y = after_stat(density),color=sex), position = "stack") +
    geom_ysidedensity(aes(x = after_stat(density),color=sex), position = "stack") +
    geom_smooth(method='lm', linetype = "dashed",aes(color=sex)) +
    geom_smooth(method='lm', linetype = "solid", group="all") +
    labs(x = "Cortisol increase (nmol/l)", y="Left thalamus volume (mm³)") +
    theme(axis.text.x = element_text(angle = 270, vjust = .2, size=12),
          axis.text.y = element_text(size=12),
          legend.position = c(0.8, 0.15),
          legend.text = element_text(size=12),
          axis.title= element_text(size=14))
ggsave(paste("./plots/left_thalamus_vol.png"),plot = p)

p<-ggplot(data, aes(cortisol_increase,right_thalamus_volume, group=sex)) + 
  geom_point(aes(shape = sex,color = sex), size=2) +
  geom_xsidedensity(aes(y = after_stat(density),color=sex), position = "stack") +
  geom_ysidedensity(aes(x = after_stat(density),color=sex), position = "stack") +
  geom_smooth(method='lm', linetype = "dashed",aes(color=sex)) +
  geom_smooth(method='lm', linetype = "solid", group="all") +
  labs(x = "Cortisol increase (nmol/l)", y="Right thalamus volume (mm³)") +
  theme(axis.text.x = element_text(angle = 270, vjust = .2, size=12),           axis.text.y = element_text(size=12),           legend.position = c(0.8, 0.15),           legend.text = element_text(size=12),           axis.title= element_text(size=14))
ggsave(paste("./plots/right_thalamus_vol.png"),plot = p)

p<-ggplot(data, aes(cortisol_increase,left_caudatus_volume, group=sex)) + 
  geom_point(aes(shape = sex,color = sex), size=2) +
  geom_xsidedensity(aes(y = after_stat(density),color=sex), position = "stack") +
  geom_ysidedensity(aes(x = after_stat(density),color=sex), position = "stack") +
  geom_smooth(method='lm', linetype = "dashed",aes(color=sex)) +
  geom_smooth(method='lm', linetype = "solid", group="all") +
  labs(x = "Cortisol increase (nmol/l)", y="Left caudatus volume (mm³)") +
  theme(axis.text.x = element_text(angle = 270, vjust = .2, size=12),           axis.text.y = element_text(size=12),           legend.position = c(0.8, 0.15),           legend.text = element_text(size=12),           axis.title= element_text(size=14))
ggsave(paste("./plots/left_caudatus_vol.png"),plot = p)

p<-ggplot(data, aes(cortisol_increase,right_caudatus_volume, group=sex)) + 
  geom_point(aes(shape = sex,color = sex), size=2) +
  geom_xsidedensity(aes(y = after_stat(density),color=sex), position = "stack") +
  geom_ysidedensity(aes(x = after_stat(density),color=sex), position = "stack") +
  geom_smooth(method='lm', linetype = "dashed",aes(color=sex)) +
  geom_smooth(method='lm', linetype = "solid", group="all") +
  labs(x = "Cortisol increase (nmol/l)", y="Right caudatus volume (mm³)") +
  theme(axis.text.x = element_text(angle = 270, vjust = .2, size=12),           axis.text.y = element_text(size=12),           legend.position = c(0.8, 0.15),           legend.text = element_text(size=12),           axis.title= element_text(size=14))
ggsave(paste("./plots/right_caudatus_vol.png"),plot = p)

p<-ggplot(data, aes(cortisol_increase,left_accumbens_volume, group=sex)) + 
  geom_point(aes(shape = sex,color = sex), size=2) +
  geom_xsidedensity(aes(y = after_stat(density),color=sex), position = "stack") +
  geom_ysidedensity(aes(x = after_stat(density),color=sex), position = "stack") +
  geom_smooth(method='lm', linetype = "dashed",aes(color=sex)) +
  geom_smooth(method='lm', linetype = "solid", group="all") +
  labs(x = "Cortisol increase (nmol/l)", y="Left accumbens volume (mm³)") +
  theme(axis.text.x = element_text(angle = 270, vjust = .2, size=12),           axis.text.y = element_text(size=12),           legend.position = c(0.8, 0.15),           legend.text = element_text(size=12),           axis.title= element_text(size=14))
ggsave(paste("./plots/left_accumbens_vol.png"),plot = p)

p<-ggplot(data, aes(cortisol_increase,right_accumbens_volume, group=sex)) + 
  geom_point(aes(shape = sex,color = sex), size=2) +
  geom_xsidedensity(aes(y = after_stat(density),color=sex), position = "stack") +
  geom_ysidedensity(aes(x = after_stat(density),color=sex), position = "stack") +
  geom_smooth(method='lm', linetype = "dashed",aes(color=sex)) +
  geom_smooth(method='lm', linetype = "solid", group="all") +
  labs(x = "Cortisol increase (nmol/l)", y="Right accumbens volume (mm³)") +
  theme(axis.text.x = element_text(angle = 270, vjust = .2, size=12),           axis.text.y = element_text(size=12),           legend.position = c(0.8, 0.15),           legend.text = element_text(size=12),           axis.title= element_text(size=14))
ggsave(paste("./plots/right_accumbens_vol.png"),plot = p)

p<-ggplot(data, aes(cortisol_increase,left_putamen_volume, group=sex)) + 
  geom_point(aes(shape = sex,color = sex), size=2) +
  geom_xsidedensity(aes(y = after_stat(density),color=sex), position = "stack") +
  geom_ysidedensity(aes(x = after_stat(density),color=sex), position = "stack") +
  geom_smooth(method='lm', linetype = "dashed",aes(color=sex)) +
  geom_smooth(method='lm', linetype = "solid", group="all") +
  labs(x = "Cortisol increase (nmol/l)", y="Left putamen volume (mm³)") +
  theme(axis.text.x = element_text(angle = 270, vjust = .2, size=12),           axis.text.y = element_text(size=12),           legend.position = c(0.8, 0.15),           legend.text = element_text(size=12),           axis.title= element_text(size=14))
ggsave(paste("./plots/left_putamen_vol.png"),plot = p)

p<-ggplot(data, aes(cortisol_increase,right_putamen_volume, group=sex)) + 
  geom_point(aes(shape = sex,color = sex), size=2) +
  geom_xsidedensity(aes(y = after_stat(density),color=sex), position = "stack") +
  geom_ysidedensity(aes(x = after_stat(density),color=sex), position = "stack") +
  geom_smooth(method='lm', linetype = "dashed",aes(color=sex)) +
  geom_smooth(method='lm', linetype = "solid", group="all") +
  labs(x = "Cortisol increase (nmol/l)", y="Right putamen volume (mm³)") +
  theme(axis.text.x = element_text(angle = 270, vjust = .2, size=12),           axis.text.y = element_text(size=12),           legend.position = c(0.8, 0.15),           legend.text = element_text(size=12),           axis.title= element_text(size=14))
ggsave(paste("./plots/right_putamen_vol.png"),plot = p)

p<-ggplot(data, aes(cortisol_increase,left_hippocampus_volume, group=sex)) + 
  geom_point(aes(shape = sex,color = sex), size=2) +
  geom_xsidedensity(aes(y = after_stat(density),color=sex), position = "stack") +
  geom_ysidedensity(aes(x = after_stat(density),color=sex), position = "stack") +
  geom_smooth(method='lm', linetype = "dashed",aes(color=sex)) +
  geom_smooth(method='lm', linetype = "solid", group="all") +
  labs(x = "Cortisol increase (nmol/l)", y="Left hippocampus volume (mm³)") +
  theme(axis.text.x = element_text(angle = 270, vjust = .2, size=12),           axis.text.y = element_text(size=12),           legend.position = c(0.8, 0.15),           legend.text = element_text(size=12),           axis.title= element_text(size=14))
ggsave(paste("./plots/left_hippocampus_vol.png"),plot = p)

p<-ggplot(data, aes(cortisol_increase,right_hippocampus_volume, group=sex)) + 
  geom_point(aes(shape = sex,color = sex), size=2) +
  geom_xsidedensity(aes(y = after_stat(density),color=sex), position = "stack") +
  geom_ysidedensity(aes(x = after_stat(density),color=sex), position = "stack") +
  geom_smooth(method='lm', linetype = "dashed",aes(color=sex)) +
  geom_smooth(method='lm', linetype = "solid", group="all") +
  labs(x = "Cortisol increase (nmol/l)", y="Right hippocampus volume (mm³)") +
  theme(axis.text.x = element_text(angle = 270, vjust = .2, size=12),           axis.text.y = element_text(size=12),           legend.position = c(0.8, 0.15),           legend.text = element_text(size=12),           axis.title= element_text(size=14))
ggsave(paste("./plots/right_hippocampus_vol.png"),plot = p)

p<-ggplot(data, aes(cortisol_increase,left_amygdala_volume, group=sex)) + 
  geom_point(aes(shape = sex,color = sex), size=2) +
  geom_xsidedensity(aes(y = after_stat(density),color=sex), position = "stack") +
  geom_ysidedensity(aes(x = after_stat(density),color=sex), position = "stack") +
  geom_smooth(method='lm', linetype = "dashed",aes(color=sex)) +
  geom_smooth(method='lm', linetype = "solid", group="all") +
  labs(x = "Cortisol increase (nmol/l)", y="Left amygdala volume (mm³)") +
  theme(axis.text.x = element_text(angle = 270, vjust = .2, size=12),           axis.text.y = element_text(size=12),           legend.position = c(0.8, 0.15),           legend.text = element_text(size=12),           axis.title= element_text(size=14))
ggsave(paste("./plots/left_amygdala_vol.png"),plot = p)

p<-ggplot(data, aes(cortisol_increase,right_amygdala_volume, group=sex)) + 
  geom_point(aes(shape = sex,color = sex), size=2) +
  geom_xsidedensity(aes(y = after_stat(density),color=sex), position = "stack") +
  geom_ysidedensity(aes(x = after_stat(density),color=sex), position = "stack") +
  geom_smooth(method='lm', linetype = "dashed",aes(color=sex)) +
  geom_smooth(method='lm', linetype = "solid", group="all") +
  labs(x = "Cortisol increase (nmol/l)", y="Right amygdala volume (mm³)") +
  theme(axis.text.x = element_text(angle = 270, vjust = .2, size=12),           axis.text.y = element_text(size=12),           legend.position = c(0.8, 0.15),           legend.text = element_text(size=12),           axis.title= element_text(size=14))
ggsave(paste("./plots/right_amygdala_vol.png"),plot = p)


p<-ggplot(data, aes(cortisol_increase,left_cACC_thickness, group=sex)) + 
  geom_point(aes(shape = sex,color = sex), size=2) +
  geom_xsidedensity(aes(y = after_stat(density),color=sex), position = "stack") +
  geom_ysidedensity(aes(x = after_stat(density),color=sex), position = "stack") +
  geom_smooth(method='lm', linetype = "dashed",aes(color=sex)) +
  geom_smooth(method='lm', linetype = "solid", group="all") +
  labs(x = "Cortisol increase (nmol/l)", y="Left cACC thickness (mm)") +
  theme(axis.text.x = element_text(angle = 270, vjust = .2, size=12),           axis.text.y = element_text(size=12),           legend.position = c(0.8, 0.15),           legend.text = element_text(size=12),           axis.title= element_text(size=14))
ggsave(paste("./plots/left_cACC_thick.png"),plot = p)

p<-ggplot(data, aes(cortisol_increase,right_cACC_thickness, group=sex)) + 
  geom_point(aes(shape = sex,color = sex), size=2) +
  geom_xsidedensity(aes(y = after_stat(density),color=sex), position = "stack") +
  geom_ysidedensity(aes(x = after_stat(density),color=sex), position = "stack") +
  geom_smooth(method='lm', linetype = "dashed",aes(color=sex)) +
  geom_smooth(method='lm', linetype = "solid", group="all") +
  labs(x = "Cortisol increase (nmol/l)", y="Right cACC thickness (mm)") +
  theme(axis.text.x = element_text(angle = 270, vjust = .2, size=12),           axis.text.y = element_text(size=12),           legend.position = c(0.8, 0.15),           legend.text = element_text(size=12),           axis.title= element_text(size=14))
ggsave(paste("./plots/right_cACC_thick.png"),plot = p)

p<-ggplot(data, aes(cortisol_increase,left_rACC_thickness, group=sex)) + 
  geom_point(aes(shape = sex,color = sex), size=2) +
  geom_xsidedensity(aes(y = after_stat(density),color=sex), position = "stack") +
  geom_ysidedensity(aes(x = after_stat(density),color=sex), position = "stack") +
  geom_smooth(method='lm', linetype = "dashed",aes(color=sex)) +
  geom_smooth(method='lm', linetype = "solid", group="all") +
  labs(x = "Cortisol increase (nmol/l)", y="Left rACC thickness (mm)") +
  theme(axis.text.x = element_text(angle = 270, vjust = .2, size=12),           axis.text.y = element_text(size=12),           legend.position = c(0.8, 0.15),           legend.text = element_text(size=12),           axis.title= element_text(size=14))
ggsave(paste("./plots/left_rACC_thick.png"),plot = p)

p<-ggplot(data, aes(cortisol_increase,right_rACC_thickness, group=sex)) + 
  geom_point(aes(shape = sex,color = sex), size=2) +
  geom_xsidedensity(aes(y = after_stat(density),color=sex), position = "stack") +
  geom_ysidedensity(aes(x = after_stat(density),color=sex), position = "stack") +
  geom_smooth(method='lm', linetype = "dashed",aes(color=sex)) +
  geom_smooth(method='lm', linetype = "solid", group="all") +
  labs(x = "Cortisol increase (nmol/l)", y="Right rACC thickness (mm)") +
  theme(axis.text.x = element_text(angle = 270, vjust = .2, size=12),           axis.text.y = element_text(size=12),           legend.position = c(0.8, 0.15),           legend.text = element_text(size=12),           axis.title= element_text(size=14))
ggsave(paste("./plots/right_rACC_thick.png"),plot = p)

p<-ggplot(data, aes(cortisol_increase,left_PCC_thickness, group=sex)) + 
  geom_point(aes(shape = sex,color = sex), size=2) +
  geom_xsidedensity(aes(y = after_stat(density),color=sex), position = "stack") +
  geom_ysidedensity(aes(x = after_stat(density),color=sex), position = "stack") +
  geom_smooth(method='lm', linetype = "dashed",aes(color=sex)) +
  geom_smooth(method='lm', linetype = "solid", group="all") +
  labs(x = "Cortisol increase (nmol/l)", y="Left PCC thickness (mm)") +
  theme(axis.text.x = element_text(angle = 270, vjust = .2, size=12),           axis.text.y = element_text(size=12),           legend.position = c(0.8, 0.15),           legend.text = element_text(size=12),           axis.title= element_text(size=14))
ggsave(paste("./plots/left_PCC_thick.png"),plot = p)

p<-ggplot(data, aes(cortisol_increase,right_PCC_thickness, group=sex)) + 
  geom_point(aes(shape = sex,color = sex), size=2) +
  geom_xsidedensity(aes(y = after_stat(density),color=sex), position = "stack") +
  geom_ysidedensity(aes(x = after_stat(density),color=sex), position = "stack") +
  geom_smooth(method='lm', linetype = "dashed",aes(color=sex)) +
  geom_smooth(method='lm', linetype = "solid", group="all") +
  labs(x = "Cortisol increase (nmol/l)", y="Right PCC thickness (mm)") +
  theme(axis.text.x = element_text(angle = 270, vjust = .2, size=12),           axis.text.y = element_text(size=12),           legend.position = c(0.8, 0.15),           legend.text = element_text(size=12),           axis.title= element_text(size=14))
ggsave(paste("./plots/right_PCC_thick.png"),plot = p)

p<-ggplot(data, aes(cortisol_increase,left_parahippocampus_thickness, group=sex)) + 
  geom_point(aes(shape = sex,color = sex), size=2) +
  geom_xsidedensity(aes(y = after_stat(density),color=sex), position = "stack") +
  geom_ysidedensity(aes(x = after_stat(density),color=sex), position = "stack") +
  geom_smooth(method='lm', linetype = "dashed",aes(color=sex)) +
  geom_smooth(method='lm', linetype = "solid", group="all") +
  labs(x = "Cortisol increase (nmol/l)", y="Left parahippocampus thickness (mm)") +
  theme(axis.text.x = element_text(angle = 270, vjust = .2, size=12),           axis.text.y = element_text(size=12),           legend.position = c(0.8, 0.15),           legend.text = element_text(size=12),           axis.title= element_text(size=14))
ggsave(paste("./plots/left_parahippocampus_thick.png"),plot = p)

p<-ggplot(data, aes(cortisol_increase,right_parahippocampus_thickness, group=sex)) + 
  geom_point(aes(shape = sex,color = sex), size=2) +
  geom_xsidedensity(aes(y = after_stat(density),color=sex), position = "stack") +
  geom_ysidedensity(aes(x = after_stat(density),color=sex), position = "stack") +
  geom_smooth(method='lm', linetype = "dashed",aes(color=sex)) +
  geom_smooth(method='lm', linetype = "solid", group="all") +
  labs(x = "Cortisol increase (nmol/l)", y="Right parahippocampus thickness (mm)") +
  theme(axis.text.x = element_text(angle = 270, vjust = .2, size=12),           axis.text.y = element_text(size=12),           legend.position = c(0.8, 0.15),           legend.text = element_text(size=12),           axis.title= element_text(size=14))
ggsave(paste("./plots/right_parahippocampus_thick.png"),plot = p)

p<-ggplot(data, aes(cortisol_increase,left_lateral_orbitofrontal_thickness, group=sex)) + 
  geom_point(aes(shape = sex,color = sex), size=2) +
  geom_xsidedensity(aes(y = after_stat(density),color=sex), position = "stack") +
  geom_ysidedensity(aes(x = after_stat(density),color=sex), position = "stack") +
  geom_smooth(method='lm', linetype = "dashed",aes(color=sex)) +
  geom_smooth(method='lm', linetype = "solid", group="all") +
  labs(x = "Cortisol increase (nmol/l)", y="Left lateral orbitofrontal thickness (mm)") +
  theme(axis.text.x = element_text(angle = 270, vjust = .2, size=12),           axis.text.y = element_text(size=12),           legend.position = c(0.8, 0.15),           legend.text = element_text(size=12),           axis.title= element_text(size=14))
ggsave(paste("./plots/left_lateral_orbitofrontal_thick.png"),plot = p)

p<-ggplot(data, aes(cortisol_increase,right_lateral_orbitofrontal_thickness, group=sex)) + 
  geom_point(aes(shape = sex,color = sex), size=2) +
  geom_xsidedensity(aes(y = after_stat(density),color=sex), position = "stack") +
  geom_ysidedensity(aes(x = after_stat(density),color=sex), position = "stack") +
  geom_smooth(method='lm', linetype = "dashed",aes(color=sex)) +
  geom_smooth(method='lm', linetype = "solid", group="all") +
  labs(x = "Cortisol increase (nmol/l)", y="Right lateral orbitofrontal thickness (mm)") +
  theme(axis.text.x = element_text(angle = 270, vjust = .2, size=12),           axis.text.y = element_text(size=12),           legend.position = c(0.8, 0.15),           legend.text = element_text(size=12),           axis.title= element_text(size=14))
ggsave(paste("./plots/right_lateral_orbitofrontal_thick.png"),plot = p)

p<-ggplot(data, aes(cortisol_increase,left_medial_orbitofrontal_thickness, group=sex)) + 
  geom_point(aes(shape = sex,color = sex), size=2) +
  geom_xsidedensity(aes(y = after_stat(density),color=sex), position = "stack") +
  geom_ysidedensity(aes(x = after_stat(density),color=sex), position = "stack") +
  geom_smooth(method='lm', linetype = "dashed",aes(color=sex)) +
  geom_smooth(method='lm', linetype = "solid", group="all") +
  labs(x = "Cortisol increase (nmol/l)", y="Left medial orbitofrontal thickness (mm)") +
  theme(axis.text.x = element_text(angle = 270, vjust = .2, size=12),           axis.text.y = element_text(size=12),           legend.position = c(0.8, 0.15),           legend.text = element_text(size=12),           axis.title= element_text(size=14))
ggsave(paste("./plots/left_medial_orbitofrontal_thick.png"),plot = p)

p<-ggplot(data, aes(cortisol_increase,right_medial_orbitofrontal_thickness, group=sex)) + 
  geom_point(aes(shape = sex,color = sex), size=2) +
  geom_xsidedensity(aes(y = after_stat(density),color=sex), position = "stack") +
  geom_ysidedensity(aes(x = after_stat(density),color=sex), position = "stack") +
  geom_smooth(method='lm', linetype = "dashed",aes(color=sex)) +
  geom_smooth(method='lm', linetype = "solid", group="all") +
  labs(x = "Cortisol increase (nmol/l)", y="Right medial orbitofrontal thickness (mm)") +
  theme(axis.text.x = element_text(angle = 270, vjust = .2, size=12),           axis.text.y = element_text(size=12),           legend.position = c(0.8, 0.15),           legend.text = element_text(size=12),           axis.title= element_text(size=14))
ggsave(paste("./plots/right_medial_orbitofrontal_thick.png"),plot = p)

data.cort<-data[c("ID", "cortisol_minus75", "cortisol_minus1", "cortisol_plus15",  "cortisol_plus30",
                  "cortisol_plus50", "cortisol_plus65",  "cortisol_plus80", "cortisol_plus95", "cortisol_plus110")]
data.cort["shape"]<-as.factor(round(runif(nrow(data.cort), 0, 5),0))

sp<-data.cort %>%
  mutate(row_number = as.factor(row_number())) %>%
  gather(columns, responses, 2:9, factor_key=T) %>%
  ggplot(aes(x = columns, y = responses, group = row_number, color = row_number, shape = shape)) +
  geom_point(aes(stroke=1.5), show.legend = FALSE) +
  geom_line(show.legend = FALSE)
sp +
  labs(y="Cortisol (nmol/l)") +
  scale_x_discrete(name ="Timepoint collection of saliva samples", 
                   label=c("-75","-1","+15","+30","+50","+65","+80","+95","+110"))+
  annotate('rect', xmin=2, xmax=4, ymin=0, ymax=25, alpha=.2, fill='red')+
  annotate("text", x = 3, y = 22, size = unit(8, "pt"), label = substitute(paste('Scan',italic('STRESS'))))+
  theme(axis.text = element_text(size=12), axis.title= element_text(size=14))
  
citation("haven")
citation("tidyverse")
citation("psych")
citation("ggplot2")
citation("ggside")
citation("labelled")           
